#
# spec file for package gnome-font-viewer
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gnome-font-viewer
Version:        45.0
Release:        1.1
Summary:        A font viewer utility for GNOME
License:        GPL-2.0-or-later
Group:          System/GUI/GNOME
URL:            https://gitlab.gnome.org/GNOME/gnome-font-viewer
Source0:        https://download.gnome.org/sources/gnome-font-viewer/45/%{name}-%{version}.tar.xz

BuildRequires:  appstream-glib
BuildRequires:  desktop-file-utils
BuildRequires:  meson >= 0.50.0
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(glib-2.0) >= 2.56.0
BuildRequires:  pkgconfig(gnome-desktop-4)
BuildRequires:  pkgconfig(gtk4) >= 4.5.0
BuildRequires:  pkgconfig(harfbuzz) >= 0.9.9
BuildRequires:  pkgconfig(libadwaita-1)
Conflicts:      gnome-utils < 3.3.1

%description
A utility to let you see the installed fonts at a glance.

%lang_package

%prep
%autosetup -p1

%build
%meson \
	%{nil}
%meson_build

%install
%meson_install
%find_lang %{name}

%check
desktop-file-validate %{buildroot}%{_datadir}/applications/org.gnome.font-viewer.desktop
appstream-util validate-relax --nonet %{buildroot}%{_datadir}/metainfo/org.gnome.font-viewer.appdata.xml
%meson_test

%files
%license COPYING
%doc NEWS
%{_bindir}/%{name}
%{_bindir}/gnome-thumbnail-font
%{_datadir}/applications/org.gnome.font-viewer.desktop
%{_datadir}/dbus-1/services/org.gnome.font-viewer.service
%dir %{_datadir}/thumbnailers
%{_datadir}/thumbnailers/%{name}.thumbnailer
%{_datadir}/metainfo/org.gnome.font-viewer.appdata.xml
%{_datadir}/icons/hicolor/*/apps/org.gnome.font-viewer*.svg

%files lang -f %{name}.lang

%changelog
* Mon Sep 18 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.0:
  + Updated translations.
* Sat Jul 15 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.alpha:
  + Fonts 45.alpha comes with a new look courtesy of the new
    libadwaita 1.4 widgets.
  + Updated translations.
* Mon Mar 20 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.0:
  + Fonts 44.0 comes with general consistency improvements to the
    application:
  - The app now provides standard shortcuts like Ctrl+Q and
    Ctrl+F.
  - New widgetry allows for navigation via the back mouse button,
    alt+arrows, and touchscreen swipes.
  - Various buttons can now be used with mnemonics.
  + Updated translations.
* Mon Mar  6 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.rc:
  + Updated translations.
* Thu Feb 23 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.beta:
  + The app now provides standard shortcuts like Ctrl+Q and Ctrl+F
  + New widgetry allows for navigation via the back mouse button,
    alt+arrows, and touchscreen swipes
  + Various buttons can now be used with mnemonics
  + Updated translations.
* Sun Sep 18 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.0:
  + Updated translations.
* Sun Sep  4 2022 Emily Gonyer <emilyyrose@gmail.com>
- Updated to versio 43.rc:
  + Updated translations.
* Mon Aug  8 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Updated to version 43.beta:
  + New "About" button in the main window.
  + Updated translations.
- Replace update-desktop-files with desktop-file-utils
  BuildRequires and run manual tests/checks of desktop file and
  metadata. Following this, drop usage of suse_update_desktop_file
  macro.
* Thu Jul 21 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.alpha:
  + Updated translations.
* Mon Mar 21 2022 Luciano Santos <luc14n0@opensuse.org>
- Update to version 42.0:
  + Updated translations.
* Tue Mar  8 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.rc:
  + Updated translations.
* Sat Feb 12 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.beta:
  + Port to gtk4.
  + Updated translations.
- From upstreams port to gtk4, replace the following BuildRequires:
  + pkgconfig(gnome-desktop-3.0) with pkgconfig(gnome-desktop-4)
  + pkgconfig(gtk+-3.0) with pkgconfig(gtk4)
  + pkgconfig(libhandy-1) with pkgconfig(libadwaita-1)
- Drop no longer explicitly checked for pkgconfig(gio-2.0)
  BuildRequires.
- Add appstream-glib BuildRequires and check section with
  meson_test macro, validate appdata during build.
* Thu Feb 10 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 42.alpha:
  + Updated translations.
- Drop 218166246e29a39e2eac8d3f06976038571b0603.patch: Fixed
  upstream.
* Thu Feb 10 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add 218166246e29a39e2eac8d3f06976038571b0603.patch: Fix build
  with meson 0.61 and newer.
* Tue Sep 21 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 41.0:
  + Updated translations.
* Mon Sep 20 2021 Stanislav Brabec <sbrabec@suse.com>
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
* Sun Mar 21 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.0:
  + Updated translations.
* Mon Feb 15 2021 Callum Farmer <gmbr3@opensuse.org>
- Update to version 40.beta:
  + Fonts 40 comes with a slight visual refresh, sporting rounded
    bottom window corners. In addition there have been general bug
    fixes and improvements.
  + The About dialog now provides a link to the repository.
  + Startup should be faster now that we use font-config's APIs
    directly.
  + Updated translations.
- New build requirement: pkgconfig(libhandy-1).
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Sun Sep 15 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.0:
  + Updated translations.
* Wed Sep  4 2019 mgorse@suse.com
- Update to version 3.33.90:
  + Fix compiler warning.
  + Translation updates.
  + Changes in version 3.33.4:
  + Add a keyboard shortcut to go Back.
  + Improve appdata file.
  + Fix font installation when filenames would collide.
  + Display an error dialog when installation fails.
  + Improve compatibility for fonts with non-unicode charmaps.
  + Fix thumbnailing for font collection files.
  + Add a Location row to the Info dialog.
  + Port to GtkFlowBox.
  + Translation updates.
- Require meson >= 0.50.0.
* Fri Mar 15 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.0:
  + Update the icon to follow the GNOME 3.32 guidelines.
  + Replace deprecated API.
  + Improve usability of the Install button.
  + Remove app menu following GNOME 3.32 guidelines.
  + Updated translations.
* Sat Sep  1 2018 bjorn.lie@gmail.com
- Update to version 3.30.0:
  + Show some more OpenType features.
  + Improve app data.
  + Updated translations.
* Tue Mar 20 2018 dimstar@opensuse.org
- Unconditionally enable translation-update-upstream: on
  Tumbleweed, this results in a NOP and for Leap in SLE paid
  translations being used (boo#1086036).
* Tue Mar 13 2018 dimstar@opensuse.org
- Update to version 3.28.0:
  + Updated translations.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Fri Feb  9 2018 luc14n0@linuxmail.org
- Update to version 3.27.90:
  + Fix icon loading.
  + Allow searching for fonts. And scrolling in both directions.
  + Turn the info dialog into a page in the main window.
  + Updated translations.
* Sun Dec 31 2017 luc14n0@linuxmail.org
- Update to version 3.27.0:
  + Show:
  - More general font information.
  - OpenType:
    . Font variation information.
    . Layout feature information.
  + Handle ttf and otf mimetypes (bgo#788383).
  + Fix a crash (bgo#789511).
  + Updated translations.
- Drop gfv-handle-ttf-otf-mime-types.patch and
  gfv-update-nb-translations.patch: Fixed upstream.
* Sat Dec 30 2017 zaitor@opensuse.org
- Add gfv-handle-ttf-otf-mime-types.patch: Handle new font/ttf and
  font/otf mime types (bgo#788383).
- Add gfv-update-nb-translations.patch: Update Norwegian Bokmål
  translations.
* Mon Sep 18 2017 luc14n0@linuxmail.org
- Update to version 3.26.0:
  + Rename to "Fonts" in AppData file too (bgo#786128).
  + Updated translations.
* Mon Aug 14 2017 zaitor@opensuse.org
- Update to version 3.25.90:
  + Use "Fonts" as user-visible application name (bgo#783640).
  + Port to use the Meson build system (bgo#783613).
  + Fix regression during startup sequence (bgo#782738).
  + Don't use gnome-common or intltool (bgo#783611).
  + Unconditionally source config.h (bgo#783612).
  + Updated translations.
- Drop intltool BuildRequires following upstream changes.
- Add meson BuildRequires and switch autotools macros configure,
  make and makeinstall to meson, meson_build and meson_install
  following upstream switch to Meson build system.
- Drop post(un) handling, desktop_database_post(un) macro no longer
  needed as file-triggers takes care of it.
* Fri May 12 2017 zaitor@opensuse.org
- Update to version 3.24.0:
  + Improve usage of GApplication API.
  + Updated translations.
* Thu Mar  2 2017 zaitor@opensuse.org
- Update to version 3.23.91:
  + Listen to fontconfig timestamp notifications instead of using
    file monitors.
  + Only show scalable fonts (bgo#771857).
- Drop gnome-font-viewer-only-show-scalable-fonts.patch: Fixed
  upstream.
* Fri Sep 23 2016 zaitor@opensuse.org
- Add gnome-font-viewer-only-show-scalable-fonts.patch: Only show
  fonts that makes sense and are modern.
- Conditionally apply translations-update-upstream BuildRequires
  and macro for non-openSUSE only.
* Tue Sep 20 2016 zaitor@opensuse.org
- Update to version 3.22.0:
  + Add an icon name to the window.
  + Don't explicitly load RTL icons.
  + Updated translations.
* Thu May 12 2016 zaitor@opensuse.org
- Update to version 3.20.2:
  + Use GApplication's internal handling of commandline arguments,
    for correcting DBus activation (bgo#765518).
  + Updated translations.
* Wed Mar 30 2016 zaitor@opensuse.org
- Update to version 3.20.0:
  + Add support for the TrueType Collection format (bgo#752005).
  + Update AppData file.
  + Fix support for HiDpi when rendering sample strings
    (bgo#742428).
  + Fix crash when no sample string can be constructed
    (bgo#757680).
  + Updated translations.
* Wed May 13 2015 zaitor@opensuse.org
- Update to version 3.16.2:
  + Updated translations.
* Tue Mar 24 2015 dimstar@opensuse.org
- Update to version 3.16.0:
  + Updated translations.
* Thu Feb 19 2015 zaitor@opensuse.org
- Update to version 3.15.90:
  + Add --help and --version (bgo#702809).
  + Update for deprecations (bgo#739224).
  + Updated translations.
* Wed Feb 18 2015 badshah400@gmail.com
- Update to version 3.14.1:
  + Fix a crash due to an uninitialized variable.
  + Updated translations.
* Tue Sep 23 2014 dimstar@opensuse.org
- Update to version 3.14.0:
  + Add X-GNOME-Utilities category to desktop file.
  + Updated translations.
* Thu Aug 21 2014 dimstar@opensuse.org
- Update to version 3.13.90:
  + Make DBus activatable.
  + Create cairo surfaces always in the main thread.
  + Show regular close button instead of Cancel in info dialog.
  + Add a title to info dialog.
  + Updated translations.
* Wed Mar 26 2014 zaitor@opensuse.org
- Update to version 3.12.0:
  + Add support for rendering complex scripts.
  + Fix header bar item positions.
  + Use header bar in the info dialog.
  + Standardize app menu Help/About/Quit.
  + Add appdata file.
- Add pkgconfig(harfbuzz) BuildRequires: New dependency.
* Tue Sep 24 2013 dimstar@opensuse.org
- Update to version 3.10.0:
  + Updated translations.
* Tue Aug 20 2013 dimstar@opensuse.org
- Update to version 3.9.90:
  + Fix back button direction for RTL locales.
  + Port to GtkStack and GtkHeaderBar.
  + Support Hi-Dpi displays.
  + Make sure not to append extra header buttons when loading a
    file.
  + Updated translations.
* Mon Mar 25 2013 dimstar@opensuse.org
- Update to version 3.8.0:
  + Updated translations.
* Thu Mar 14 2013 sbrabec@suse.cz
- Added support for translation-update-upstream.
* Tue Mar  5 2013 dimstar@opensuse.org
- Update to version 3.7.91:
  + Port to use GdStack and GdHeaderBar.
  + Updated translations.
* Wed Feb  6 2013 dimstar@opensuse.org
- Update to version 3.7.5:
  + Use a better padding for the font preview.
  + Updated translations.
* Mon Jan 14 2013 dimstar@opensuse.org
- Update to version 3.7.4:
  + Don't paint a white background below font thumbnails.
  + Add keywords to the desktop file.
  + Don't call g_type_init(), depends on GLib 2.35.1.
  + Updated translations.
* Tue Jan  8 2013 dimstar@opensuse.org
- Update to version 3.7.3:
  + Show an error dialog when we fail to load a font file.
  + Fix a crasher when opening a non-existing file from the command
    line.
  + Updated translations.
* Thu Dec  6 2012 dimstar@opensuse.org
- Update to version 3.6.2:
  + Fix Install button not refreshing correctly when opening an
    installed font.
  + Fix a crasher when installing a new font.
  + Updated translations.
* Tue Nov 13 2012 dimstar@opensuse.org
- Update to version 3.6.1:
  + Fix application name showing in dialog title.
  + Fix a possible crasher when updating the font list.
  + Updated translations.
* Mon Sep 24 2012 dimstar@opensuse.org
- Update to version 3.6.0:
  + Updated translations.
* Mon Sep 17 2012 zaitor@opensuse.org
- Update to version 3.5.92:
  + Updated translations.
* Fri Sep  7 2012 vuntz@opensuse.org
- Add pkgconfig(fontconfig) BuildRequires: new dependency
  introduced in 3.5.2.
- Do not add System category to gnome-font-viewer.desktop: it moves
  the application to the System Tools menu, which we don't want.
* Tue Sep  4 2012 dimstar@opensuse.org
- Update to version 3.5.91:
  + Use the libgd submodule for GdMainToolbar
  + Updated translations.
* Mon Aug 20 2012 dimstar@opensuse.org
- Update to version 3.5.90:
  + Improve performance when loading the application's overview
  + Make loading of the overview model completely asynchronous
  + Updated translations.
* Tue Jul 17 2012 dimstar@opensuse.org
- Update to version 3.5.4:
  + Fix a compiler warning
  + Updated translations.
* Mon Jun 25 2012 dimstar@opensuse.org
- Update to version 3.5.3:
  + Refactor thumbnailing code to use g_io_scheduler_push_job() for
    robustness
  + Updated translations.
* Mon Jun  4 2012 dimstar@opensuse.org
- Update to version 3.5.2:
  + Fall back to C locale when constructing the sample string
    before picking an entirely random-glyph string.
  + Flip font widget orientation for RTL locales.
  + Always pick a valid size for fixed-size fonts.
  + Fix missing string compression before display for PS fonts.
  + Improve string sanitizing before display for information
    fetched out of the font files.
  + Monitor fontconfig directories for new fonts.
  + Support fontconfig XDG_DATA_HOME directory for font install, if
    present.
  + Set a fallback icon when thumbnails are not available.
  + Force black on white for font text display.
  + Quit with Ctrl+Q.
  + Use GResource for UI files.
  + Correctly update the install button when install complete.
- Add System, Settings and Utility categories to
  gnome-font-viewer.desktop now that it's not hidden anymore.
* Wed May  2 2012 dimstar@opensuse.org
- Update to version 3.5.1:
  + Rewrite the user interface using a GNOME 3 style.
  + Implement a gallery mode for all the fonts on the system.
  + Add an application menu and an about dialog.
  + Make "Install" button insensitive if the font is already
    installed.
  + Port the thumbnailer to cairo drawing.
  + Updated translations.
- Add pkgconfig(gnome-desktop-3.0) BuildRequires: new dependency.
* Mon Mar 26 2012 vuntz@opensuse.org
- Update to version 3.4.0:
  + Updated translations.
* Mon Mar 19 2012 zaitor@opensuse.org
- Update to version 3.3.92:
  + Fix unused variables GCC warnings.
  + Updated translations.
* Tue Nov  1 2011 dimstar@opensuse.org
- Initial package, version 3.3.2.1, split out from gnome-utils.
